@@ -47,7 +47,7 @@ exports.serve = function (nylon_path, port) {
         cluster.on('exit', (worker, code, signal) => {
             console.log("code::"+code);
             console.log("signal::"+signal);
-            if(signal!="SIGINT"){
+            if(code!=-1){
                 cluster.fork();
                 logger.info('worker ' + worker.process.pid + ' died');
             }
@@ -107,6 +107,10 @@ exports.serve = function (nylon_path, port) {
             logger.error(err);
             process.exit(1);
         });
+       
+        process.on("SIGINT",function(){
+            process.exit(-1);
+        });
 
         module.exports = app;
     }
