@@ -2,10 +2,12 @@ const jwt = require('jsonwebtoken');
 //const SECRET_KEY = "จริงๆแล้วก็ไม่รู้ว่าจะใส่อะไรดีที่เป็นความลับอะนะ";
 
 function parseHeader(req) {
+//console.log(req.headers);
     var list = {},
-        rc = req.headers.Authorization;
+        rc = req.headers.authorization;
+    //console.log(rc);
     var parts = rc.split(' ');
-    list[parts.shift().trim()] = parts[1];
+    list[parts[0]] = parts[1];
     return list;
 }
 
@@ -15,6 +17,7 @@ module.exports = function (options) {
     options = options || ["*"];
     return function authenticate(req, res, next) {
         var oauth = parseHeader(req);
+	//console.log(oauth.JWT);
         if (oauth.JWT) {
             jwt.verify(oauth.JWT, req.SECRET_KEY, function (err, decode) {
                 if (err) {
